@@ -4,14 +4,14 @@ use strict;
 use warnings;
 
 package Mail::DKIM;
-our $VERSION = 0.34;
+our $VERSION = '0.16';
 
 1;
 __END__
 
 =head1 NAME
 
-Mail::DKIM - Signs/verifies Internet mail with DKIM/DomainKey signatures
+Mail::DKIM - Signs/verifies Internet mail using DKIM message signatures
 
 =head1 SYNOPSIS
 
@@ -19,7 +19,7 @@ Mail::DKIM - Signs/verifies Internet mail with DKIM/DomainKey signatures
   use Mail::DKIM::Verifier;
 
   # create a verifier object
-  my $dkim = Mail::DKIM::Verifier->new();
+  my $dkim = Mail::DKIM::Verifier->new_object();
 
   # read an email from stdin, pass it into the verifier
   while (<STDIN>)
@@ -44,13 +44,14 @@ parts into this module, for use in other programs.
 
 The Mail::DKIM module uses an object-oriented interface. You use one of
 two different classes, depending on whether you are signing or verifying
-a message. To sign, use the L<Mail::DKIM::Signer> class. To verify, use the
-L<Mail::DKIM::Verifier> class. Simple, eh?
+a message. To sign, use the Mail::DKIM::Signer class. To verify, use the
+Mail::DKIM::Verifier class. Simple, eh?
 
 =head1 SEE ALSO
 
-L<Mail::DKIM::Signer>,
-L<Mail::DKIM::Verifier>
+Mail::DKIM::Signer
+
+Mail::DKIM::Verifier
 
 http://jason.long.name/dkimproxy/
 
@@ -60,10 +61,15 @@ The DKIM standard is still in development, so by the time you read this,
 this module may already be broken with regards to the latest DKIM
 specification.
 
-The "sender signing policy" component is still under construction. The
-sender signing policy is supposed to identify the practice of the message
-author, so you could for example reject a message from an author who claims
-they always sign their messages. See L<Mail::DKIM::Policy>.
+One feature that has not been implemented yet is the "sender signing policy".
+I.e. this library will tell you whether the signature is valid, but will
+not lookup the signing policy for the author of the message.
+
+This library uses two different crypto libraries: Crypt::OpenSSL::RSA and
+Crypt::RSA. This redundancy is undesirable, but so far I have not figured
+out how to load base64-encoded key data using Crypt::RSA, and I have not
+figured out to sign/verify an already-computed message digest using
+Crypt::OpenSSL::RSA.
 
 =head1 AUTHOR
 
@@ -71,7 +77,7 @@ Jason Long, E<lt>jlong@messiah.eduE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2006-2007 by Messiah College
+Copyright (C) 2006 by Messiah College
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.6 or,
