@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-# Copyright 2005-2007 Messiah College. All rights reserved.
+# Copyright 2005 Messiah College. All rights reserved.
 # Jason Long <jlong@messiah.edu>
 
 # Copyright (c) 2004 Anthony D. Urso. All rights reserved.
@@ -27,29 +27,33 @@ sub init
 		or croak "no signature specified";
 }
 
-# similar to code in DkCommon.pm
 sub add_header
 {
-	#Note: canonicalization of headers is performed
-	#in finish_header()
+	my $self = shift;
+	my ($line) = @_;
+
+	#croak "header parse error \"$line\"" unless ($line =~ /:/);
+
+	$line =~ s/\015\012\z//s;
+	push @{$self->{myheaders}},
+		$self->canonicalize_header($line) . "\015\012";
 }
 
 sub finish_header
 {
 	my $self = shift;
-	my %args = @_;
 
 	# Headers are canonicalized in the order specified by the h= tag.
 	# However, in the case of multiple instances of the same header name,
 	# the headers will be canonicalized in reverse order (i.e. "from
 	# the bottom of the header field block to the top").
 	#
-	# This is described in 5.4 of RFC4871.
+	# This is described in 5.4 of draft-allman-dkim-base-01.
 
 	# Since the bottom-most headers are to get precedence, we reverse
 	# the headers here... (now the first header matching a particular
 	# name is the header to insert)
-	my @mess_headers = reverse @{$args{Headers}};
+	my @mess_headers = reverse @{$self->{myheaders}};
 
 	# presence of a h= tag is mandatory...
 	unless (defined $self->{Signature}->headerlist)
@@ -80,37 +84,37 @@ sub finish_header
 					# once, we'll get the next header in line
 					splice @mess_headers, $i, 1;
 
-					$hdr =~ s/\015\012\z//s;
-					$self->output($self->canonicalize_header($hdr) . "\015\012");
+					$self->output($hdr);
 					last inner_loop;
 				}
 			}
 		}
 	}
+
+	$self->output("\015\012");
 }
 
 sub add_body
 {
 	my $self = shift;
-	my ($multiline) = @_;
+	my ($line) = @_;
 
-	$multiline = $self->canonicalize_body($multiline);
+	$line = $self->canonicalize_body($line);
 	if ($self->{Signature})
 	{
 		if (my $limit = $self->{Signature}->body_count)
 		{
 			my $remaining = $limit - $self->{body_count};
-			if (length($multiline) > $remaining)
+			if (length($line) > $remaining)
 			{
-				$self->{body_truncated} +=
-					length($multiline) - $remaining;
-				$multiline = substr($multiline, 0, $remaining);
+				$self->{body_truncated} += length($line) - $remaining;
+				$line = substr($line, 0, $remaining);
 			}
 		}
 	}
 
-	$self->{body_count} += length($multiline);
-	$self->output($multiline);
+	$self->{body_count} += length($line);
+	$self->output($line);
 }
 
 sub finish_body
