@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-# Copyright 2005-2007 Messiah College. All rights reserved.
+# Copyright 2005 Messiah College. All rights reserved.
 # Jason Long <jlong@messiah.edu>
 
 # Copyright (c) 2004 Anthony D. Urso. All rights reserved.
@@ -10,12 +10,13 @@
 use strict;
 use warnings;
 
-use Mail::Address;
+use Mail::DKIM::Algorithm::rsa_sha1;
+use Mail::DKIM::Signature;
 
 package Mail::DKIM::Common;
 use base "Mail::DKIM::MessageParser";
 use Carp;
-our $VERSION = 0.40;
+our $VERSION = "0.12";
 
 sub new
 {
@@ -23,17 +24,23 @@ sub new
 	return $class->new_object(@_);
 }
 
+sub get_algorithm_class
+{
+	my $self = shift;
+	croak "wrong number of arguments" unless (@_ == 1);
+	my ($algorithm) = @_;
+
+	my $class = $algorithm eq "rsa-sha1" ? "Mail::DKIM::Algorithm::rsa_sha1" :
+		die "unknown algorithm $algorithm\n";
+	return $class;
+}
+
 sub add_header
 {
 	my $self = shift;
 	my ($line) = @_;
 
-	foreach my $algorithm (@{$self->{algorithms}})
-	{
-		$algorithm->add_header($line);
-	}
-
-	if ($line =~ /^([^:]+?)\s*:(.*)/s)
+	if ($line =~ /^([^:]+)\s*:(.*)/s)
 	{
 		my $field_name = lc $1;
 		my $contents = $2;
@@ -49,10 +56,6 @@ sub add_body
 	{
 		$self->{algorithm}->add_body(@_);
 	}
-	foreach my $algorithm (@{$self->{algorithms}})
-	{
-		$algorithm->add_body(@_);
-	}
 }
 
 sub handle_header
@@ -68,17 +71,6 @@ sub handle_header
 	$self->{headers_by_name}->{$field_name} = $contents;
 }
 
-sub init
-{
-	my $self = shift;
-	$self->SUPER::init(@_);
-
-	#initialize variables
-	$self->{headers} = [];
-	$self->{headers_by_name} = {};
-	$self->{header_field_names} = [];
-}
-
 sub load
 {
 	my $self = shift;
@@ -108,7 +100,7 @@ sub message_attributes
 
 	if ($self->{headers_by_name}->{sender})
 	{
-		my @list = Mail::Address->parse($self->{headers_by_name}->{sender});
+		my @list = parse Mail::Address($self->{headers_by_name}->{sender});
 		if ($list[0])
 		{
 			push @attributes, "sender=<" . $list[0]->address . ">";
@@ -116,7 +108,7 @@ sub message_attributes
 	}
 	elsif ($self->{headers_by_name}->{from})
 	{
-		my @list = Mail::Address->parse($self->{headers_by_name}->{from});
+		my @list = parse Mail::Address($self->{headers_by_name}->{from});
 		if ($list[0])
 		{
 			push @attributes, "from=<" . $list[0]->address . ">";
@@ -148,10 +140,10 @@ sub message_originator
 
 	if ($self->{headers_by_name}->{from})
 	{
-		my @list = Mail::Address->parse($self->{headers_by_name}->{from});
-		return $list[0] if @list;
+		my @list = parse Mail::Address($self->{headers_by_name}->{from});
+		return $list[0];
 	}
-	return Mail::Address->new;
+	return undef;
 }
 
 sub message_sender
@@ -161,15 +153,15 @@ sub message_sender
 
 	if ($self->{headers_by_name}->{sender})
 	{
-		my @list = Mail::Address->parse($self->{headers_by_name}->{sender});
-		return $list[0] if @list;
+		my @list = parse Mail::Address($self->{headers_by_name}->{sender});
+		return $list[0];
 	}
 	if ($self->{headers_by_name}->{from})
 	{
-		my @list = Mail::Address->parse($self->{headers_by_name}->{from});
-		return $list[0] if @list;
+		my @list = parse Mail::Address($self->{headers_by_name}->{from});
+		return $list[0];
 	}
-	return Mail::Address->new;
+	return undef;
 }
 
 sub result
